@@ -1,11 +1,14 @@
 var searchData=
 [
-  ['tan',['tan',['../group__avr__math.html#gaa2c2303658b8b2555bc97cce3f806bda',1,'math.h']]],
-  ['tanh',['tanh',['../group__avr__math.html#gaf4b72825a245b794090135251f0ead22',1,'math.h']]],
+  ['tan',['tan',['../group__avr__math.html#gaf0e253671796652ca53c00714f4793b3',1,'math.h']]],
+  ['tanf',['tanf',['../group__avr__math.html#gae3b3e7cab6090db81726369baad8fa98',1,'math.h']]],
+  ['tanh',['tanh',['../group__avr__math.html#ga3e83f8feb91d52313fc34b20372da620',1,'math.h']]],
+  ['tanhf',['tanhf',['../group__avr__math.html#gaa572bac8e97acf75f85a7e4c62afa8ab',1,'math.h']]],
   ['time',['time',['../group__avr__time.html#ga26c7d1dbf93fa8c23c5effbacec91f8c',1,'time(time_t *timer):&#160;time.c'],['../group__avr__time.html#ga26c7d1dbf93fa8c23c5effbacec91f8c',1,'time(time_t *timer):&#160;time.c']]],
   ['timer_5fenable_5fint',['timer_enable_int',['../group__deprecated__items.html#ga46f0b87ccc2ab63dea1ff28207270b82',1,'deprecated.h']]],
   ['toascii',['toascii',['../group__ctype.html#ga21d5ec3792b2704ecca5778b758dd91f',1,'ctype.h']]],
   ['tolower',['tolower',['../group__ctype.html#ga9ba1fce7148e9b63ca6296e02c79bedd',1,'ctype.h']]],
   ['toupper',['toupper',['../group__ctype.html#ga924ed052807e23cfa160d5f171cf5e2a',1,'ctype.h']]],
-  ['trunc',['trunc',['../group__avr__math.html#ga1883497d16352bd92875499f1b39a4b6',1,'math.h']]]
+  ['trunc',['trunc',['../group__avr__math.html#ga1d368e2bd61c560427eb648a17e2ad55',1,'math.h']]],
+  ['truncf',['truncf',['../group__avr__math.html#gacb32151c0aa04c0dfcfb2834c04eb384',1,'math.h']]]
 ];
