@@ -5,5 +5,6 @@ var searchData=
   ['random',['random',['../group__avr__stdlib.html#ga114aeb1751119382aaf3340355b22cfd',1,'random(void):&#160;random.c'],['../group__avr__stdlib.html#ga114aeb1751119382aaf3340355b22cfd',1,'random(void):&#160;random.c']]],
   ['random_5fr',['random_r',['../group__avr__stdlib.html#gaa99a0733f06d2b9960a1401c2721af1e',1,'random_r(unsigned long *__ctx):&#160;random.c'],['../group__avr__stdlib.html#gaa99a0733f06d2b9960a1401c2721af1e',1,'random_r(unsigned long *ctx):&#160;random.c']]],
   ['realloc',['realloc',['../group__avr__stdlib.html#gafd300bad8b4dd2e88b07d464d76c92aa',1,'realloc(void *__ptr, size_t __size) __ATTR_MALLOC__:&#160;realloc.c'],['../group__avr__stdlib.html#gafd300bad8b4dd2e88b07d464d76c92aa',1,'realloc(void *ptr, size_t len):&#160;realloc.c']]],
-  ['round',['round',['../group__avr__math.html#ga6eb04604d801054c5a2afe195d1dd75d',1,'math.h']]]
+  ['round',['round',['../group__avr__math.html#ga0da66246ab167d37056944ef70327412',1,'math.h']]],
+  ['roundf',['roundf',['../group__avr__math.html#ga5f193a8df6bcb255c963dbf60fa9934c',1,'math.h']]]
 ];
